pub struct EffectiveExportBinding { /* private fields */ }Expand description
One canonical declaration that an exported name resolves to.
Implementations
Sourceimpl EffectiveExportBinding
impl EffectiveExportBinding
Sourcepub const fn origin_file(&self) -> FileId
pub const fn origin_file(&self) -> FileId
Module that owns the resolved declaration or opaque external surface.
Sourcepub const fn namespace_source(self) -> Option<FileId>
pub const fn namespace_source(self) -> Option<FileId>
Source module represented by a namespace-object export.
Sourcepub const fn is_implicit_default(self) -> bool
pub const fn is_implicit_default(self) -> bool
Whether this binding is the implicit default export of an SFC file.