Module project
fallow_
graph
3.29.0
Module project
Module Items
Structs
In crate fallow_
graph
fallow_graph
Module
project
Centralized project state with file registry and workspace metadata.
Structs

Project
State
Discovered files and workspace packages for one analysis run.