pub struct MissingExportTarget {
pub specifier: String,
pub paths: Vec<PathBuf>,
}Expand description
The missing paths that the exports map of a project package names for
one unresolved bare specifier.
Fields
specifier: StringThe import specifier, for example store/enums.
paths: Vec<PathBuf>The absolute paths that the matched exports entry names.